#!/usr/bin/env python3

# © Canonical 2015
# Licensed under AGPLv3

"""
Tanuki End to End Test

Usage:
  e2e-snap-rev.py [-i] <configfile>
  e2e-snap-rev.py --default-config

Options:
  -h --help             Show this screen
  --default-config      Show default configuration
  --server              MessageHub URL override
  --specmgr             SpecManager URL override
  -i                    Interactive
"""

import docopt
import time
import uuid

from e2e import E2e, logger, GRY


class E2eSnapRevision(E2e):

    def run(self):
        self.annotate('Starting.')
        logger.info('SpecManager : %s', self.specmgr_url)
        logger.info('MessageHub  : %s', self.server)
        self.cleanup_manifests()
        self.create_manifest()
        self.cleanup_specs()
        self.annotate('As Developer or QA, Create Test Spec via Spec Manager')
        self.create_spec()
        self.prompt('As Lab Owner, Run agent first to register with Message Hub')  # NOQA
        self.run_agent(reg_only=True)
        self.pause()
        self.submit_snap_revision()
        self.annotate('Sleeping 1s to wait for propagation to hub', color=GRY)
        time.sleep(1)
        self.annotate('As Lab Owner, Running agent')
        self.annotate(
            'Should pick up at least 1 Test Opportunity, '
            'provision and run tests', color=GRY)
        self.annotate('Note this can also run continously in daemon mode',
                      color=GRY)
        self.pause()
        self.run_agent()
        self.prompt('Completed agent run')
        self.annotate('As Developer or QA, Checking results via Result Enumerator')
        self.check_multiple_results()
        self.delete_spec()


if __name__ == '__main__':
    arguments = docopt.docopt(__doc__, version='Tanuki E2e Proto 1')
    e2e = E2eSnapRevision(arguments)
    # For this case we need a unique image_name
    e2e.image_name += uuid.uuid4().hex
    e2e.run()
    exit(e2e.exit_code)
